@@ -14,6 +14,7 @@
 from metlog.exceptions import EnvironmentNotFoundError
 from metlog.client import MetlogClient
 from metlog.config import client_from_text_config
+from metlog.config import client_from_dict_config
 from metlog.senders import DebugCaptureSender
 from mock import Mock
 from mock import patch
@@ -227,22 +228,34 @@ def test_handshake_sender_with_backend():
             call_args = mock_pool.send.call_args[0]
             eq_(call_args[0], expected)
 
+
 def test_plugin_override():
     cfg_txt = """
     [metlog]
     sender_class = metlog.senders.DebugCaptureSender
+
     [metlog_plugin_exception]
     override=True
     provider=metlog.tests.plugin:config_plugin
     """
     client = client_from_text_config(cfg_txt, 'metlog')
-    eq_('my_plugin', client.exception.__name__)
+    eq_('dummy', client.dummy.metlog_name)
 
     cfg_txt = """
     [metlog]
     sender_class = metlog.senders.DebugCaptureSender
     [metlog_plugin_exception]
-    provider=metlog.tests.plugin:config_plugin
+    provider=metlog.tests.plugin_exception:config_plugin
     """
     # Failure to set an override argument will throw an exception
     assert_raises(SyntaxError, client_from_text_config, cfg_txt, 'metlog')
+
+
+def test_load_config_multiple_times():
+    cfg = {'logger': 'addons-marketplace-dev',
+           'sender': {'class': 'metlog.senders.UdpSender',
+           'host': ['logstash1', 'logstash2'],
+           'port': '5566'}}
+
+    client_from_dict_config(cfg)
+    client_from_dict_config(cfg)
